==> oeli_0.7.3.tar.gz: oeli/R/oeli-package.R <==
#' @keywords internal
#' @useDynLib oeli, .registration=TRUE
"_PACKAGE"

## usethis namespace: start
#' @importFrom benchmarkme get_cpu
#' @importFrom benchmarkme get_ram
#' @importFrom checkmate assert_atomic_vector
#' @importFrom checkmate assert_character
#' @importFrom checkmate assert_choice
#' @importFrom checkmate assert_count
#' @importFrom checkmate assert_data_frame
#' @importFrom checkmate assert_flag
#' @importFrom checkmate assert_function
#' @importFrom checkmate assert_int
#' @importFrom checkmate assert_integerish
#' @importFrom checkmate assert_list
#' @importFrom checkmate assert_matrix
#' @importFrom checkmate assert_names
#' @importFrom checkmate assert_number
#' @importFrom checkmate assert_numeric
#' @importFrom checkmate assert_string
#' @importFrom checkmate assert_subset
#' @importFrom checkmate assert_vector
#' @importFrom checkmate check_atomic_vector
#' @importFrom checkmate check_character
#' @importFrom checkmate check_choice
#' @importFrom checkmate check_count
#' @importFrom checkmate check_data_frame
#' @importFrom checkmate check_directory_exists
#' @importFrom checkmate check_flag
#' @importFrom checkmate check_function
#' @importFrom checkmate check_int
#' @importFrom checkmate check_integerish
#' @importFrom checkmate check_list
#' @importFrom checkmate check_matrix
#' @importFrom checkmate check_names
#' @importFrom checkmate check_number
#' @importFrom checkmate check_numeric
#' @importFrom checkmate check_string
#' @importFrom checkmate check_subset
#' @importFrom checkmate makeAssertion
#' @importFrom checkmate makeAssertionFunction
#' @importFrom checkmate makeTestFunction
#' @importFrom checkmate test_atomic_vector
#' @importFrom checkmate test_class
#' @importFrom checkmate test_int
#' @importFrom checkmate test_list
#' @importFrom checkmate test_string
#' @importFrom checkmate vname
#' @importFrom cli cli_abort
#' @importFrom cli cli_inform
#' @importFrom cli cli_text
#' @importFrom cli cli_warn
#' @importFrom cli style_hyperlink
#' @importFrom ggplot2 ggplot
#' @importFrom ggplot2 theme_void
#' @importFrom hexSticker sticker
#' @importFrom R6 R6Class
#' @importFrom Rcpp compileAttributes
#' @importFrom SimMultiCorrData calc_theory
#' @importFrom SimMultiCorrData rcorrvar
#' @importFrom SimMultiCorrData valid_corr
#' @importFrom stats cor
#' @importFrom stats dist
#' @importFrom stats dnorm
#' @importFrom stats rnorm
#' @importFrom stats runif
#' @importFrom tools package_native_routine_registration_skeleton
#' @importFrom utils combn
#' @importFrom utils head
#' @importFrom utils tail
## usethis namespace: end
NULL

==> oeli_0.7.4.tar.gz: oeli/R/oeli-package.R <==
#' @keywords internal
#' @useDynLib oeli, .registration=TRUE
"_PACKAGE"

## usethis namespace: start
#' @importFrom benchmarkme get_cpu
#' @importFrom benchmarkme get_ram
#' @importFrom checkmate assert
#' @importFrom checkmate assert_atomic_vector
#' @importFrom checkmate assert_character
#' @importFrom checkmate assert_choice
#' @importFrom checkmate assert_count
#' @importFrom checkmate assert_data_frame
#' @importFrom checkmate assert_flag
#' @importFrom checkmate assert_function
#' @importFrom checkmate assert_int
#' @importFrom checkmate assert_integerish
#' @importFrom checkmate assert_list
#' @importFrom checkmate assert_matrix
#' @importFrom checkmate assert_names
#' @importFrom checkmate assert_number
#' @importFrom checkmate assert_numeric
#' @importFrom checkmate assert_string
#' @importFrom checkmate assert_subset
#' @importFrom checkmate assert_vector
#' @importFrom checkmate check_atomic_vector
#' @importFrom checkmate check_character
#' @importFrom checkmate check_choice
#' @importFrom checkmate check_class
#' @importFrom checkmate check_count
#' @importFrom checkmate check_data_frame
#' @importFrom checkmate check_directory_exists
#' @importFrom checkmate check_flag
#' @importFrom checkmate check_function
#' @importFrom checkmate check_int
#' @importFrom checkmate check_integerish
#' @importFrom checkmate check_list
#' @importFrom checkmate check_matrix
#' @importFrom checkmate check_names
#' @importFrom checkmate check_number
#' @importFrom checkmate check_numeric
#' @importFrom checkmate check_path_for_output
#' @importFrom checkmate check_string
#' @importFrom checkmate check_subset
#' @importFrom checkmate makeAssertion
#' @importFrom checkmate makeAssertionFunction
#' @importFrom checkmate makeTestFunction
#' @importFrom checkmate test_atomic_vector
#' @importFrom checkmate test_class
#' @importFrom checkmate test_int
#' @importFrom checkmate test_list
#' @importFrom checkmate test_matrix
#' @importFrom checkmate test_string
#' @importFrom checkmate vname
#' @importFrom cli cli_abort
#' @importFrom cli cli_inform
#' @importFrom cli cli_text
#' @importFrom cli cli_warn
#' @importFrom cli style_hyperlink
#' @importFrom dplyr arrange
#' @importFrom dplyr bind_rows
#' @importFrom dplyr filter
#' @importFrom future multisession
#' @importFrom future plan
#' @importFrom future.apply future_lapply
#' @importFrom ggplot2 ggplot
#' @importFrom ggplot2 theme_void
#' @importFrom glue glue
#' @importFrom hexSticker sticker
#' @importFrom progressr handler_progress
#' @importFrom progressr handlers
#' @importFrom progressr progressor
#' @importFrom R6 R6Class
#' @importFrom Rcpp compileAttributes
#' @importFrom SimMultiCorrData calc_theory
#' @importFrom SimMultiCorrData rcorrvar
#' @importFrom SimMultiCorrData valid_corr
#' @importFrom stats cor
#' @importFrom stats dist
#' @importFrom stats dnorm
#' @importFrom stats rnorm
#' @importFrom stats runif
#' @importFrom tibble as_tibble
#' @importFrom tibble tibble
#' @importFrom tools package_native_routine_registration_skeleton
#' @importFrom utils combn
#' @importFrom utils head
#' @importFrom utils tail
## usethis namespace: end
NULL
